@@ -3,6 +3,7 @@ from functools import lru_cache, wraps
 import itertools
 from pathlib import Path
 from typing import Any, Callable, TYPE_CHECKING, Sequence
+import warnings
 import numpy as np
 from numpy.typing import ArrayLike, DTypeLike
 from warnings import warn
@@ -12,6 +13,7 @@ import operator
 from .labeledarray import LabeledArray
 from .imgarray import ImgArray
 from .axesmixin import AxesMixin
+from .tiled import TiledAccessor
 from ._utils import _misc, _transform, _structures, _filters, _deconv, _corr, _docs
 
 from impy.utils.axesop import slice_axes, switch_slice, complement_axes, find_first_appeared
@@ -28,10 +30,11 @@ from impy._const import Const
 
 if TYPE_CHECKING:
     from dask.array.core import Array as DaskArray
-
+    from impy.axes import AxesTuple
 
 class LazyImgArray(AxesMixin):
     additional_props = ["_source", "_metadata", "_name"]
+    tiled: TiledAccessor[LazyImgArray] = TiledAccessor()
     
     def __init__(
         self,
@@ -89,7 +92,7 @@ class LazyImgArray(AxesMixin):
         return self.value.ndim
     
     @property
-    def shape(self):
+    def shape(self) -> AxesTuple[int]:
         """Shape of the array."""
         return self.axes.tuple(self.value.shape)
         
@@ -109,7 +112,7 @@ class LazyImgArray(AxesMixin):
         return self.value.itemsize
     
     @property
-    def chunksize(self):
+    def chunksize(self) -> AxesTuple[int]:
         """Chunk size of the array."""
         return self.axes.tuple(self.value.chunksize)
         
@@ -539,10 +542,11 @@ class LazyImgArray(AxesMixin):
         depth: int = 16,
         boundary="reflect",
         dtype: DTypeLike = None,
-        args: tuple = None,
-        kwargs: dict[str, Any] = None
+        args: tuple | None = None,
+        kwargs: dict[str, Any] | None = None
     ) -> DaskArray:
         from dask import array as da
+
         if args is None:
             args = ()
         if kwargs is None:
@@ -1035,26 +1039,14 @@ class LazyImgArray(AxesMixin):
     @check_input_and_output_lazy
     def tiled_lowpass_filter(self, cutoff: float = 0.2, order: int = 2, overlap: int = 16, *,
                              dims: Dims = None, update: bool = False) -> LazyImgArray:
-        from ._utils._skimage import _get_ND_butterworth_filter
-        self = self.as_float()
-        c_axes = complement_axes(dims, self.axes)
-        ndims = len(dims)
-        cutoff = check_nd(cutoff, ndims)
-        if all((c >= 0.5*np.sqrt(ndims) or c <= 0) for c in cutoff):
-            return self
-        
-        depth = switch_slice(dims, self.axes, overlap, 0)
-        
-        def func(arr):
-            arr = xp.asarray(arr)
-            shape = arr.shape
-            weight = _get_ND_butterworth_filter(shape, cutoff, order, False, True)
-            ft = xp.asarray(weight) * xp.fft.rfftn(arr)
-            ift = xp.fft.irfftn(ft, s=shape)
-            return ift
-        
-        out = self._apply_map_overlap(func, c_axes=c_axes, depth=depth, boundary="reflect")
-        return out
+        warnings.warn(
+            "`tiled_lowpass_filter` is deprecated. Please use "
+            f"`img.tiled({overlap=}).lowpass_filter({cutoff=}, {order=})` instead.",
+            DeprecationWarning,
+        )
+        return self.tiled(
+            chunks=self.chunksizesof(dims), overlap=overlap, dims=dims,
+        ).lowpass_filter(cutoff, order)
     
     @_docs.copy_docs(ImgArray.proj)
     @same_dtype
@@ -1065,7 +1057,7 @@ class LazyImgArray(AxesMixin):
         elif not isinstance(axis, str):
             raise TypeError("`axis` must be str.")
         axisint = [self.axisof(a) for a in axis]
-        
+
         if method == "mean":
             projection = getattr(da, method)(self.value, axis=tuple(axisint), dtype=np.float32)
         else:
